.. include:: ../README.rst
   :start-line: 9
   :end-before: Project links

Table of contents
-----------------

.. toctree::
   :maxdepth: 2

   usage
   integrations
   contributing
   versionhistory
   py-modindex
